'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.noop = noop;
exports.getSelectedBlock = getSelectedBlock;
exports.getToggleStyleFunc = getToggleStyleFunc;
exports.findEntities = findEntities;
exports.getSelectionText = getSelectionText;
exports.getApplyEntityFunc = getApplyEntityFunc;
exports.getToggleEntityFunc = getToggleEntityFunc;
exports.getCurrentEntity = getCurrentEntity;
exports.inlineStyleComponentFactory = inlineStyleComponentFactory;

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _draftJs = require('draft-js');

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

var _rcEditorUtils = require('rc-editor-utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj["default"] = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function noop(args) {}
function getSelectedBlock(editorState) {
    var currentContent = editorState.getCurrentContent();
    var selection = editorState.getSelection();
    return currentContent.getBlockForKey(selection.getStartKey());
}
function getToggleStyleFunc(callbacks) {
    return function toggleStyle(styleName) {
        var getEditorState = callbacks.getEditorState;
        var setEditorState = callbacks.setEditorState;

        setEditorState(_draftJs.RichUtils.toggleInlineStyle(getEditorState(), styleName));
    };
}
function findEntities(entityType) {
    return function findEntitiesFunc(contentBlock, callback) {
        contentBlock.findEntityRanges(function (character) {
            var entityKey = character.getEntity();
            return entityKey !== null && _draftJs.Entity.get(entityKey).getType() === entityType;
        }, callback);
    };
}
function getSelectionText(editorState, selection) {
    var anchorKey = selection.getAnchorKey();
    var currentContent = editorState.getCurrentContent();
    var currentBlock = currentContent.getBlockForKey(anchorKey);
    return currentBlock.getText();
}
function getApplyEntityFunc(callbacks) {
    return function applyEntity(entityType) {
        var data = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
        var entityMode = arguments.length <= 2 || arguments[2] === undefined ? 'MUTABLE' : arguments[2];
        var getEditorState = callbacks.getEditorState;
        var setEditorState = callbacks.setEditorState;

        var editorState = getEditorState();
        var selection = editorState.getSelection();
        var currentEntity = getCurrentEntity(editorState);
        var entityKey = null;
        if (currentEntity && _draftJs.Entity.get(currentEntity).getType() === entityType) {
            console.log('>> currentEntity', currentEntity);
            entityKey = _draftJs.Entity.replaceData(currentEntity, data);
        } else {
            entityKey = _draftJs.Entity.create(entityType, entityMode, data);
        }
        var replacedContent = _draftJs.Modifier.applyEntity(editorState.getCurrentContent(), selection, entityKey);
        return setEditorState(_draftJs.EditorState.push(editorState, replacedContent, 'toggle-block'));
    };
}
function getToggleEntityFunc(callbacks) {
    return function toggleEntity(entityType) {
        var data = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
        var entityMode = arguments.length <= 2 || arguments[2] === undefined ? 'MUTABLE' : arguments[2];
        var getEditorState = callbacks.getEditorState;
        var setEditorState = callbacks.setEditorState;

        var editorState = getEditorState();
        var selection = editorState.getSelection();
        var entityKey = null;
        var currentEntity = getCurrentEntity(editorState);
        if (!currentEntity || _draftJs.Entity.get(currentEntity).getType() !== entityType) {
            entityKey = _draftJs.Entity.create(entityType, entityMode, data);
        }
        var replacedContent = _draftJs.Modifier.applyEntity(editorState.getCurrentContent(), selection, entityKey);
        return setEditorState(_draftJs.EditorState.push(editorState, replacedContent, 'toggle-block'));
    };
}
function getCurrentEntity(editorState) {
    var entity = void 0;
    var selection = editorState.getSelection();
    var start = selection.getStartOffset();
    var end = selection.getEndOffset();
    if (start === end && start === 0) {
        end = -1;
    } else if (start === end) {
        start = start - 1;
    }
    var block = getSelectedBlock(editorState);
    for (var i = start; i < end; i++) {
        var currentEntity = block.getEntityAt(i);
        if (!currentEntity) {
            entity = undefined;
            break;
        }
        if (i === start) {
            entity = currentEntity;
        } else {
            if (entity !== currentEntity) {
                entity = undefined;
                break;
            }
        }
    }
    return entity;
}
function inlineStyleComponentFactory(name) {
    var style = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    return {
        constructor: function constructor() {
            var callbacks = {
                getEditorState: noop,
                setEditorState: noop
            };
            var upperName = name.toUpperCase();
            var toggleStyle = getToggleStyleFunc(callbacks);
            return {
                name: name,
                callbacks: callbacks,
                component: function component(props) {
                    var _classnames;

                    var currentStyle = (0, _rcEditorUtils.getCurrentInlineStyle)(callbacks.getEditorState());
                    var classNames = (0, _classnames3["default"])((_classnames = {}, _defineProperty(_classnames, 'editor-icon', true), _defineProperty(_classnames, 'editor-icon-' + name, true), _defineProperty(_classnames, 'active', currentStyle.has(upperName)), _classnames));
                    return React.createElement('span', { onMouseDown: function onMouseDown() {
                            return toggleStyle(upperName);
                        }, className: classNames });
                }
            };
        },

        config: {}
    };
}
function modifyBlockForContentState(contentState, selectionState, operation) {
    var startKey = selectionState.getStartKey();
    var endKey = selectionState.getEndKey();
    var blockMap = contentState.getBlockMap();
    var newBlocks = blockMap.toSeq().skipUntil(function (_, k) {
        return k === startKey;
    }).takeUntil(function (_, k) {
        return k === endKey;
    }).concat(Map([[endKey, blockMap.get(endKey)]])).map(operation);
    return contentState.merge({
        blockMap: blockMap.merge(newBlocks),
        selectionBefore: selectionState,
        selectionAfter: selectionState
    });
}